summaryrefslogtreecommitdiff
path: root/src/mongo/db/ops/modifier_interface.h
diff options
context:
space:
mode:
authorAndrew Morrow <acm@10gen.com>2013-07-16 19:53:43 -0400
committerAndrew Morrow <acm@10gen.com>2013-07-19 12:03:57 -0400
commit23170882979115ad884818ea765047382d8ecf65 (patch)
tree6952e93211172a3673d9b3935ea4a710916ad060 /src/mongo/db/ops/modifier_interface.h
parent228ad77a39a471b323095691dbbe1a9fd7150f38 (diff)
downloadmongo-23170882979115ad884818ea765047382d8ecf65.tar.gz
SERVER-10162 Generate properly grouped oplog update components in new update framework
Diffstat (limited to 'src/mongo/db/ops/modifier_interface.h')
-rw-r--r--src/mongo/db/ops/modifier_interface.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/mongo/db/ops/modifier_interface.h b/src/mongo/db/ops/modifier_interface.h
index 476681e5639..3341de8ba20 100644
--- a/src/mongo/db/ops/modifier_interface.h
+++ b/src/mongo/db/ops/modifier_interface.h
@@ -24,6 +24,8 @@
namespace mongo {
+ class LogBuilder;
+
/**
* Abstract base class for update "modifiers" (a.k.a "$ operators"). To create a new
* operator, implement a new derived class.
@@ -104,10 +106,9 @@ namespace mongo {
virtual Status apply() const = 0 ;
/**
* Returns OK and registers the result of this mod in 'logRoot', the document that
* would eventually become a log entry. The mod must have kept enough state to
* be able to produce the log record (see idempotency note below). This call may be
* issued even if apply() was not.
*
* If the mod could not be logged, returns an error status with a reason description.
*
@@ -119,8 +120,7 @@ namespace mongo {
* for logging purposes. An array based operator may check the contents of the
* array before operating on it.
*/
- virtual Status log(mutablebson::Element logRoot) const = 0;
-
+ virtual Status log(LogBuilder* logBuilder) const = 0;
};
struct ModifierInterface::ExecInfo {
@@ -104,10 +106,9 @@ namespace mongo {
virtual Status apply() const = 0 ;
/**
- * Returns OK and registers the result of this mod in 'logRoot', the document that
- * would eventually become a log entry. The mod must have kept enough state to
- * be able to produce the log record (see idempotency note below). This call may be
- * issued even if apply() was not.
+ * Returns OK and records the result of this mod in the provided LogBuilder. The mod
+ * must have kept enough state to be able to produce the log record (see idempotency
+ * note below). This call may be issued even if apply() was not.
*
* If the mod could not be logged, returns an error status with a reason description.